# resthys

Une interface REST partielle pour Noethys

[![Built with Cookiecutter Django](https://img.shields.io/badge/built%20with-Cookiecutter%20Django-ff69b4.svg)](https://github.com/pydanny/cookiecutter-django/)

## Installation
### Requirements

On a Debian-based host - running at least Debian Stretch, you will need the
following packages:
- python3
- virtualenv
- python3-psycopg2 (optional, in case of a PostgreSQL database)
- python3-mysqldb (optional, in case of a mysql database)

Note: if you're serving the application with uWSGI and NGINX on a sub location, ensure
that you've added `route-run = fixpathinfo:` to your uWSGI configuration (from
[v2.0.11](https://uwsgi-docs.readthedocs.io/en/latest/Changelog-2.0.11.html#fixpathinfo-routing-action)).

### Step by step

In waiting for a complete `Makefile`, you will have to follow those steps to
install the application.

It assumes that you have downloaded the last release of resthys,
extracted it and that you moved to that folder.

1.  Start by creating a new virtual environment under `./venv` and activate it:

        $ virtualenv --system-site-packages ./venv
        $ source ./venv/bin/activate

2.  Install the required Python packages depending on your environment:

        $ pip install -r requirements/production.txt
        ... or ...
        $ pip install -r requirements/development.txt

3.  Configure the application by setting the proper environment variables
    depending on your environment. You can use the `config.env.example` which
    give you the main variables with example values.

        $ cp config.env.example config.env
        $ nano config.env

    Note that this `./config.env` file will be loaded by default when the
    application starts. If you don't want that, just move this file away or set
    the `DJANGO_READ_CONFIG_FILE` environment variable to `false`.

4.  Configure a MySQL Noethys database or copy an example file from Noethys
    sources: https://github.com/Noethys/Noethys/blob/master/noethys/Static/Exemples/EXEMPLE_alsh_DATA.dat
    then

        $ cp EXEMPLE_alsh_DATA.dat noethys.db
        $ cp EXEMPLE_alsh_DATA.dat noethys.test.db

5.  Inspect the Noethys DB:

        $ ./manage.py inspectdb --database=noethys > noethysdb/models.py

6.  Run the tests:

        $ ./manage.py test

7.  Create the database tables - it assumes that you have created the database
    and set the proper configuration to use it:

        $ ./manage.py migrate

That's it! You should now be able to start the Django development server to
check that everything is working fine with:

    $ ./manage.py runserver

## Structure
### Overview

All the application files - e.g. Django code including settings, templates and
statics - are located into the `resthys/`. It should
permit in a near future to distribute the application as a Python package and
install it system-wide.

Two environments are defined - either for requirements and settings:
- `development`: for local application development and testing. It uses a
  SQLite3 database and enable debugging by default, add some useful settings
  and applications for development purpose - i.e. the `django-debug-toolbar`.
- `production`: for production. It checks that configuration is set and
  correct, try to optimize performances and enforce some settings - i.e. HTTPS
  related ones.

### Local changes

You can override and extend statics and templates locally. This can be useful
if you have to change the logo for a specific instance for example. For that,
just put your files under the `local/static/` and `local/templates/` folders.

Regarding the statics, do not forget to collect them after that. Note also that
the `local/` folder is ignored by *git*.

### Variable content

All the variable content - e.g. user-uploaded media, collected statics - are
stored inside the `var/` folder. It is also ignored by *git* as it's specific
to each application installation.

So, you will have to configure your Web server to serve the `var/media/` and
`var/static/` folders, which should point to `/media/` and `/static/`,
respectively.

## License

resthys is developed by Cliss XXI and licensed under the
[AGPLv3+](LICENSE).
